# !/usr/bin/python
# -*- coding: utf-8 -*-

# Glitter Toolkit

__authors__ = ["Jan Jokela <janjokela@gmail.com>"]
__licenses__ = ["LICENSE.LGPL"]
__description__ = "A CairoTexture from a SVG"

import clutter
import cairo
import rsvg
from clutter.cluttercairo import CairoTexture

class SVGTexture(CairoTexture):
    """ Creates a CairoTexture based on a given SVG """

    def __init__(self, uri, width, height):
        
        """
        uri (str) -- SVG source location, standard uri format
        width (int) -- width in pixels
        height (int) -- height in pixels
        """
        
        CairoTexture.__init__(self, width, height)
        
        self.uri = uri
        self.width = width
        self.height = height
        
        #self.svg_context = cairo.svg.Context()
        self.context = self.cairo_create()
        
        #print rsvg.Handle
        #print 'loading file'
        self.svg = rsvg.Handle(self.uri)
        #print 'rendering'
        self.matrix = cairo.Matrix((self.width * 1.0 / self.svg.props.width),0,0,(self.height * 1.0 / self.svg.props.height),0,0)
        #print self.svg.props.width, self.svg.props.height, self.svg.props.em, self.svg.props.ex
        self.context.transform(self.matrix)
        self.svg.render_cairo(self.context)
               
        self.context.close_path()
        
        self.context.stroke() 
        #print 'done'
        del(self.context)
        
    def update(self):
        
        pass        
        
