# !/usr/bin/python
# -*- coding: utf-8 -*-

# Glitter Toolkit

__authors__ = ["Jan Jokela <janjokela@gmail.com>"]
__licenses__ = ["LICENSE.LGPL"]
__description__ = "Label widget" 

import gobject
import pango
import clutter

from container import Container

class Label(Container):
    """ Glitter label widget """

    def __init__(self, text='Label', font='URWGothicL', 
                 color=(100, 100, 100, 255), ellipsize=True, 
                 line_wrap=False, width_pc=100, height_pc=100, width_mm=0, 
                 height_mm=0, ratio_lock='width', ratio=0.0, x_pc=0, y_pc=0,
                 x_mm=0, y_mm=0):
        
        """
        text (str) -- text to be displayed in label
        font (str) -- font name
        color (int, int, int, int) -- text color in (r,g,b,a) format
        ellipsize (bool) -- wether text should be ellipsized (ellipsized text
                            gets cut and added three dots when text size 
                            exceeds defined width)
        line_wrap (bool) -- wether text should be line wrapped
        
        .. (*) -- refer to glitter.Container for documentation
        """

        self.text = text
        self.font = font
        self.color = color
        self.ellipsize = ellipsize
        self.line_wrap = line_wrap
        
        self.label = None
        
        Container.__init__(self, 
                           width_pc=width_pc,
                           height_pc=height_pc,
                           width_mm=width_mm,
                           height_mm=height_mm,
                           ratio_lock=ratio_lock,
                           ratio=ratio,
                           x_pc=x_pc,
                           y_pc=y_pc,
                           x_mm=x_mm,
                           y_mm=y_mm)
    
    # Property getters
    def get_text(self):
        """ Retrieve label text 
        
        return (str)
        """
        
        return self.text
        
    def get_font(self):
        """ Retrieve font name 
        
        return (str)
        """
        
        return self.font
        
    def get_color(self):
        """ Retrieve font color
        
        return (int, int, int, int) -- color in (r,g,b,a) format
        """
        
        return self.color
        
    def get_ellipsize(self):
        """ Retrieve wether text is ellipsized (ellipsized text cuts it and 
        adds three dots if text doesn't fit container width)
        
        return (bool)
        """
        
        return self.ellipsize
        
    def get_line_wrap(self):
        """ Retrieve wether text is line wraped
        
        return (bool)
        """
        
        return self.line_wrap
        
    # Property setters
    def set_text(self, value):
        """ Sets label text 
        
        value (str)
        """
        
        self.text = value
        
    def set_font(self, value):
        """ Sets font 
        
        value (str) -- font name
        """
        
        self.font = value
        
    def set_color(self, value):
        """ Set font color
        
        value (int, int, int, int) -- color in (r,g,b,a) format
        """
        
        self.color = value
        
    def set_ellipsize(self, value):
        """ Set wether text is ellipsized (ellipsized text cuts it and 
        adds three dots if text doesn't fit container width)
        
        value (bool)
        """
        
        self.ellipsize = value
        
    def set_line_wrap(self, value):
        """ Set wether text is line wraped
        
        value (bool)
        """
        
        self.line_wrap = value
    
    def update(self):
        """ Updates actor """
        
        super(Label, self).update()
        
        if not self.label:
            self._set_text()
        
        width = self.get_width_px()
        height = self.get_height_px()
        # 1.229 is a magical constant provenient directly from hell
        self.label.set_font_name(self.font + ' ' + str(int(height / 1.229)) + 'px')
        #self.label.set_width(-1)
        #self.label.set_height(-1)
        self.label.set_width(width)
        self.label.set_height(height)        
              
    def _set_text(self):
        """ Sets a clutter label """
        
        self.label = clutter.Label()
        self.label.set_text(self.text)
        self.label.set_color(self.color)
        self.label.set_line_wrap(self.line_wrap)
        if self.ellipsize:
            self.label.set_ellipsize(pango.ELLIPSIZE_END)
        #self.label.set_font_name(self.font + ' ' + str(32) + 'px')
        self.add(self.label)
        self.label.show()
        
        
gobject.type_register(Label)
