# !/usr/bin/python
# -*- coding: utf-8 -*-

# Glitter Toolkit

__authors__ = ["Jan Jokela <janjokela@gmail.com>"]
__licenses__ = ["LICENSE.LGPL"]
__description__ = "Pixbuf image" 

import gtk.gdk as gdk
import gobject
import clutter

class PixbufImage(clutter.Texture):

    """ A clutter.Texture based on a gtk.gdk.pixbuf """ 
    
    __gproperties__ = {'uri': (gobject.TYPE_STRING,
                               'pixbuf uri',
                               'pixbuf uri, standard uri formats apply',
                               'None',
                               gobject.PARAM_READWRITE),
                       'ratio': (gobject.TYPE_FLOAT,
                                 'width-height ratio',
                                 'width-height ratio, if value is 0, no ratio '
                                 'will be set',
                                 0,
                                 1000,
                                 0,
                                 gobject.PARAM_READWRITE),
                       'ratio_lock': (gobject.TYPE_STRING,
                                      'lock ratio to width or height',
                                      'lock ratio to width or height',
                                      'width',
                                      gobject.PARAM_READWRITE)    
                      }
    
    def __init__(self, uri, ratio=1.0, ratio_lock='width'):
    
        """
        uri (str) -- source location, standard uri format
        ratio (float) -- ratio depending on ratio_lock, 0.0 none is applied
        ratio_lock (str) -- locks ratio to width or height
        """
    
        self.uri = uri
        self.ratio = ratio
        self.ratio_lock = ratio_lock
        
        self.__gobject_init__(uri=self.uri, ratio=self.ratio, ratio_lock=self.ratio_lock)
    
        clutter.Texture.__init__(self)
        
        self._set_pixbuf()

    def do_get_property(self, property):
        """ Get GObject property """
    
        if property.name == 'uri':
            return self.uri
        elif property.name == 'ratio':
            return self.ratio
        elif property.name == 'ratio-lock':
            return self.ratio_lock
        else:
            raise AttributeError, 'unknown property: %s' % property.name
        
    def do_set_property(self, property, value):
        """ Set GObject property """
        
        if property.name == 'uri':
            self.uri = value
        elif property.name == 'ratio':
            self.ratio = value
        elif property.name == 'ratio-lock':
            self.ratio_lock = value
        else:
            raise AttributeError, 'unknown property: %s' % property.name   
        
    def _set_pixbuf(self):
        """ Sets pixbuf based on source """
        
        pixbuf = gdk.pixbuf_new_from_file(self.uri)
        self.set_pixbuf(pixbuf)
        
          
gobject.type_register(PixbufImage)
