# !/usr/bin/python
# -*- coding: utf-8 -*-

# Glitter Toolkit

__authors__ = ["Jan Jokela <janjokela@gmail.com>"]
__licenses__ = ["LICENSE.LGPL"]
__description__ = "Toolbar widget" 

import sys
import os

import gobject
import clutter

from container import Container
from image import Image

class Toolbar(Container):
    
    """ A Glitter Toolbar widget """
    
    def __init__(self, animate=True, width_pc=100, height_pc=100, width_mm=0, height_mm=0, 
                 ratio_lock='width', ratio=0.0, x_pc=0, y_pc=0, x_mm=0, 
                 y_mm=0):
        
        """ 
        * -- refer to Container for inherited arguments 
        """
        
        Container.__init__(self, 
                           width_pc=width_pc,
                           height_pc=height_pc,
                           width_mm=width_mm,
                           height_mm=height_mm,
                           ratio_lock=ratio_lock,
                           ratio=ratio,
                           x_pc=x_pc,
                           y_pc=y_pc,
                           x_mm=x_mm,
                           y_mm=y_mm)
        
        self.animate = animate
             
        self.background = None
        
        self.set_reactive(True)
        
        self.connect('motion-event', self.do_motion_event)
        self.connect('leave-event', self.do_leave_event)

    # Property getters
    def get_animate(self):
        """ Retrieve wether animations are enabled 
        
        return (bool)
        """
        
        return self.animate
        
    # Property setters
    def set_animate(self, value):
        """ Enable or disable animations 
        
        value (bool)
        """
        
        self.animate = value

    # Event handling
    def do_motion_event(self, stage, event):
        """ """
        pass
        
    def do_leave_event(self, stage, event):
        """ """
        pass

    def update(self):
        """ """
        
        super(Toolbar, self).update()

        if not self.background:
            self._set_elements()
        else:
            self.background.update()

    def _set_elements(self):
        """ Sets visual elements """

        background_source = os.path.join(sys.path[0], "data", "themes", 
                                         "nublo", 
                                         "toolbar_background_texture.py")
        self.background = Image(source=background_source)
        self.add(self.background)
        self.background.show()
        
        if self.animate:
            self.appear_timeline = clutter.Timeline(duration=500)
            self.appear_alpha = clutter.Alpha(self.appear_timeline,
                                              clutter.smoothstep_inc_func)
            self.appear_behaviour = clutter.BehaviourOpacity(
                                        alpha=self.appear_alpha,
                                        opacity_start=0,
                                        opacity_end=255)
            self.appear_behaviour.apply(self.background)
            self.appear_timeline.start()

        
gobject.type_register(Toolbar)
