# !/usr/bin/python
# -*- coding: utf-8 -*-

# Glitter Toolkit

__authors__ = ["Jan Jokela <janjokela@gmail.com>"]
__licenses__ = ["LICENSE.LGPL"]
__description__ = "The Glitter widget factory" 

import sys
import os

# We need to set sys.path[0] as distribution root
glitter_path = os.path.split(sys.path[0])[0]
glitter_path = os.path.split(glitter_path)[0]
#glitter_path = os.path.join(glitter_path, 'glitter')
sys.path[0] = glitter_path

import pygtk
pygtk.require('2.0')
import gtk

import clutter
import clutter.cluttergtk as cluttergtk

from glitter.stage import Stage as Stage
from glitter.frame import Frame as Frame
from glitter.box import Box
from glitter.label import Label
from glitter.toolbar import Toolbar as Toolbar
from glitter.button import Button as Button
from glitter.toggle_switch import ToggleSwitch as ToggleSwitch
from tests.glitter_gtk_window import GlitterGTKWindow as GlitterGTKWindow

class Factory(object):
    """ Widget factory """
    
    def __init__(self):

        # Lets create a stage
        self.width = 800
        self.height = 480
        self.stage = Stage()
        self.stage.set_size(self.width, self.height)
        self.stage.set_color(clutter.color_parse('Black'))
        self.stage.set_title("Glitter Widget Factory")
        # the following is set off because we are embedding in a GTK window
        #self.stage.set_user_resizable(True)
        self.stage.show()
        
        # Frames are top level widgets, just under stage.
        self.frame = Frame()
        self.stage.add(self.frame)
        self.frame.show()
        
        # Lets add a toolbar to our frame
        self.toolbar = Toolbar(height_pc=20)
        self.frame.add(self.toolbar)
        self.toolbar.show()
        
        # Lets add a button to the toolbar
        self.button = Button(text="Button", width_mm=10, height_mm=2, 
                             height_pc=80, ratio_lock='height', ratio=5.0)
        self.button.set_y_pc(10)
        self.button.set_x_pc(10)
        self.toolbar.add(self.button)
        self.button.show()
        
        # Lets add a box below our toolbar
        self.box = Box(height_pc=80)
        self.box.set_y_pc(20)
        self.frame.add(self.box)
        self.box.show()
        
        # A label for our toggle switch
        self.toggle_label1 = Label(text="Toggle switch", height_pc=10)
        self.toggle_label1.set_x_pc(10)
        self.toggle_label1.set_y_pc(10)
        self.box.add(self.toggle_label1)
        self.toggle_label1.show()
        
        # Lets add a toggle switch
        self.toggle1 = ToggleSwitch(height_pc=10, ratio_lock='height')
        self.toggle1.set_x_pc(40)
        self.toggle1.set_y_pc(10)
        self.box.add(self.toggle1)
        self.toggle1.show()       

        # A label for our second toggle
        self.toggle_label2 = Label(text="Hit or slide", height_pc=10)
        self.toggle_label2.set_x_pc(10)
        self.toggle_label2.set_y_pc(30)
        self.box.add(self.toggle_label2)
        self.toggle_label2.show()
        
        # Lets add a toggle another switch
        self.toggle2 = ToggleSwitch(height_pc=10, ratio_lock='height')
        self.toggle2.set_x_pc(40)
        self.toggle2.set_y_pc(30)
        self.box.add(self.toggle2)
        self.toggle2.show() 
        
        window = GlitterGTKWindow(self.width, self.height)
        window.start()        
        
    def destroy(self, widget, data=None):
        gtk.main_quit()

        
if __name__ == '__main__':
    Factory()
